@@ -4,7 +4,7 @@ use bevy::{
     scene::InstanceId,
 };
 use bevy_full_throttle::FullThrottlePlugin;
-use bevy_hikari::{NotGiReceiver, Volume, VoxelConeTracingPlugin};
+use bevy_hikari::{GiConfig, NotGiReceiver, Volume, VoxelConeTracingPlugin};
 use smooth_bevy_cameras::{
     controllers::orbit::{
         ControlEvent, OrbitCameraBundle, OrbitCameraController, OrbitCameraPlugin,
@@ -24,12 +24,13 @@ fn main() {
         .add_plugins(DefaultPlugins)
         .add_plugin(LookTransformPlugin)
         .add_plugin(OrbitCameraPlugin::new(true))
-        .add_plugin(VoxelConeTracingPlugin)
+        .add_plugin(VoxelConeTracingPlugin::default())
         .add_plugin(FullThrottlePlugin)
         .add_startup_system(setup)
         .add_system(scene_update)
         .add_system(light_rotate_system)
-        .add_system(camera_input_map);
+        .add_system(camera_input_map)
+        .add_system(toggle_enable_volume);
 
     app.run();
 }
@@ -244,3 +245,9 @@ pub fn camera_input_map(
     }
     events.send(ControlEvent::Zoom(scalar));
 }
+
+pub fn toggle_enable_volume(keyboard_input: Res<Input<KeyCode>>, mut config: ResMut<GiConfig>) {
+    if keyboard_input.just_pressed(KeyCode::X) {
+        config.enabled = !config.enabled;
+    }
+}
