@@ -55,18 +55,28 @@ pub use voxel::VoxelMaterialPlugin;
 /// The main plugin, registers required systems and resources.
 /// The only material registered is [`StandardMaterial`].
 /// To register custom [`Material`], add [`VoxelMaterialPlugin`] to the app.
-#[derive(Default)]
-pub struct VoxelConeTracingPlugin;
+pub struct VoxelConeTracingPlugin {
+    enabled: bool,
+}
+
+impl Default for VoxelConeTracingPlugin {
+    fn default() -> Self {
+        Self { enabled: true }
+    }
+}
 
 impl Plugin for VoxelConeTracingPlugin {
     fn build(&self, app: &mut App) {
-        app.add_plugin(VoxelPlugin)
-            .add_plugin(DeferredPlugin)
-            .add_plugin(TracingPlugin)
-            .add_plugin(OverlayPlugin)
-            .add_plugin(DeferredMaterialPlugin::<StandardMaterial>::default())
-            .add_plugin(VoxelMaterialPlugin::<StandardMaterial>::default())
-            .add_plugin(TracingMaterialPlugin::<StandardMaterial>::default());
+        app.insert_resource(GiConfig {
+            enabled: self.enabled,
+        })
+        .add_plugin(VoxelPlugin)
+        .add_plugin(DeferredPlugin)
+        .add_plugin(TracingPlugin)
+        .add_plugin(OverlayPlugin)
+        .add_plugin(DeferredMaterialPlugin::<StandardMaterial>::default())
+        .add_plugin(VoxelMaterialPlugin::<StandardMaterial>::default())
+        .add_plugin(TracingMaterialPlugin::<StandardMaterial>::default());
 
         let mut shaders = app.world.get_resource_mut::<Assets<Shader>>().unwrap();
         shaders.set_untracked(
@@ -100,6 +110,7 @@ impl Plugin for VoxelConeTracingPlugin {
 
         render_app
             .init_resource::<VolumeMeta>()
+            .add_system_to_stage(RenderStage::Extract, extract_config)
             .add_system_to_stage(RenderStage::Extract, extract_volumes)
             .add_system_to_stage(RenderStage::Prepare, prepare_volumes);
 
@@ -195,6 +206,13 @@ impl Plugin for VoxelConeTracingPlugin {
     }
 }
 
+/// The resource configures global GI options.
+#[derive(Clone)]
+pub struct GiConfig {
+    /// Is the GI effect enabled globally
+    pub enabled: bool,
+}
+
 /// Marker component for meshes not casting GI.
 #[derive(Component)]
 pub struct NotGiCaster;
@@ -261,6 +279,10 @@ pub struct VolumeMeta {
     voxel_buffers: HashMap<Entity, Buffer>,
 }
 
+fn extract_config(mut commands: Commands, config: Res<GiConfig>) {
+    commands.insert_resource(config.clone());
+}
+
 fn extract_volumes(mut commands: Commands, volumes: Query<(Entity, &Volume)>) {
     for (entity, volume) in volumes.iter() {
         commands.get_or_spawn(entity).insert(volume.clone());
@@ -275,7 +297,12 @@ fn prepare_volumes(
     mut texture_cache: ResMut<TextureCache>,
     mut volumes: Query<(Entity, &Volume)>,
     mut volume_meta: ResMut<VolumeMeta>,
+    config: Res<GiConfig>,
 ) {
+    if !config.enabled {
+        return;
+    }
+
     volume_meta.volume_uniforms.clear();
 
     for (entity, volume) in volumes.iter_mut() {
@@ -347,7 +374,7 @@ fn prepare_volumes(
         });
 
         for view in volume.views.iter().cloned() {
-            let color_texture = texture_cache.get(
+            let texture = texture_cache.get(
                 &render_device,
                 TextureDescriptor {
                     label: Some("voxel_volume_texture"),
@@ -366,9 +393,7 @@ fn prepare_volumes(
 
             commands.entity(view).insert_bundle((
                 volume_uniform_offset.clone(),
-                VolumeColorAttachment {
-                    texture: color_texture,
-                },
+                VolumeColorAttachment { texture },
                 RenderPhase::<Voxel>::default(),
             ));
         }
