@@ -1,6 +1,6 @@
 use crate::{
-    overlay::GpuScreenOverlay, GpuVolume, NotGiReceiver, Volume, VolumeBindings, VolumeMeta,
-    VolumeUniformOffset, TRACING_SHADER_HANDLE,
+    overlay::GpuScreenOverlay, GiConfig, GpuVolume, NotGiReceiver, Volume, VolumeBindings,
+    VolumeMeta, VolumeUniformOffset, TRACING_SHADER_HANDLE,
 };
 use bevy::{
     core::FloatOrd,
@@ -286,7 +286,12 @@ fn queue_tracing_meshes<M: SpecializedMaterial>(
         &mut RenderPhase<Tracing<Transparent3d>>,
         &mut RenderPhase<AmbientOcclusion>,
     )>,
+    config: Res<GiConfig>,
 ) {
+    if !config.enabled {
+        return;
+    }
+
     let draw_opaque = opaque_draw_functions
         .read()
         .get_id::<DrawTracingMesh<M>>()
