@@ -1,7 +1,7 @@
 use crate::{
-    GpuVolume, GpuVoxelBuffer, NotGiCaster, Volume, VolumeBindings, VolumeColorAttachment,
-    VolumeMeta, VolumeUniformOffset, VOXEL_ANISOTROPIC_MIPMAP_LEVEL_COUNT, VOXEL_SHADER_HANDLE,
-    VOXEL_SIZE,
+    GiConfig, GpuVolume, GpuVoxelBuffer, NotGiCaster, Volume, VolumeBindings,
+    VolumeColorAttachment, VolumeMeta, VolumeUniformOffset, VOXEL_ANISOTROPIC_MIPMAP_LEVEL_COUNT,
+    VOXEL_SHADER_HANDLE, VOXEL_SIZE,
 };
 use bevy::{
     core::FloatOrd,
@@ -582,8 +582,13 @@ pub fn queue_voxel_meshes<M: SpecializedMaterial>(
     mut pipelines: ResMut<SpecializedPipelines<VoxelPipeline>>,
     mut pipeline_cache: ResMut<RenderPipelineCache>,
     volumes: Query<&Volume, Without<VolumeView>>,
+    config: Res<GiConfig>,
     mut view_query: Query<(&VisibleEntities, &mut RenderPhase<Voxel>), With<VolumeView>>,
 ) {
+    if !config.enabled {
+        return;
+    }
+
     let draw_mesh = voxel_draw_functions
         .read()
         .get_id::<DrawVoxelMesh<M>>()
@@ -827,6 +832,12 @@ impl render_graph::Node for VoxelPassNode {
         render_context: &mut bevy::render::renderer::RenderContext,
         world: &World,
     ) -> Result<(), bevy::render::render_graph::NodeRunError> {
+        if let Some(config) = world.get_resource::<GiConfig>() {
+            if !config.enabled {
+                return Ok(());
+            }
+        }
+
         let entity = graph.get_input_entity(Self::IN_VIEW)?;
         if let Ok(volume) = self.volume_query.get_manual(world, entity) {
             for view in volume.views.iter().cloned() {
@@ -886,6 +897,12 @@ impl render_graph::Node for MipmapPassNode {
         render_context: &mut bevy::render::renderer::RenderContext,
         world: &World,
     ) -> Result<(), render_graph::NodeRunError> {
+        if let Some(config) = world.get_resource::<GiConfig>() {
+            if !config.enabled {
+                return Ok(());
+            }
+        }
+
         let pipeline = world.get_resource::<VoxelPipeline>().unwrap();
         let mut pass = render_context
             .command_encoder
@@ -942,6 +959,12 @@ impl render_graph::Node for VoxelClearPassNode {
         render_context: &mut bevy::render::renderer::RenderContext,
         world: &World,
     ) -> Result<(), render_graph::NodeRunError> {
+        if let Some(config) = world.get_resource::<GiConfig>() {
+            if !config.enabled {
+                return Ok(());
+            }
+        }
+
         let pipeline = world.get_resource::<VoxelPipeline>().unwrap();
         let mut pass = render_context
             .command_encoder
